/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.dfareporting.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.util.DateTime;

/**
 * Represents a date range.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the DFA Reporting API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class DateRange extends GenericJson {

  /**
   * The end date of the date range, inclusive. A string of the format: "yyyy-MM-dd".
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime endDate;

  /**
   * The kind of resource this is, in this case dfareporting#dateRange.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The date range relative to the date of when the report is run, one of: - "TODAY"  - "YESTERDAY"
   * - "WEEK_TO_DATE"  - "MONTH_TO_DATE"  - "QUARTER_TO_DATE"  - "YEAR_TO_DATE"  - "PREVIOUS_WEEK"
   * - "PREVIOUS_MONTH"  - "PREVIOUS_QUARTER"  - "PREVIOUS_YEAR"  - "LAST_7_DAYS"  - "LAST_30_DAYS"
   * - "LAST_90_DAYS"  - "LAST_365_DAYS"  - "LAST_24_MONTHS"
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String relativeDateRange;

  /**
   * The start date of the date range, inclusive. A string of the format: "yyyy-MM-dd".
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime startDate;

  /**
   * The end date of the date range, inclusive. A string of the format: "yyyy-MM-dd".
   * The value returned may be {@code null}.
   */
  public DateTime getEndDate() {
    return endDate;
  }

  /**
   * The end date of the date range, inclusive. A string of the format: "yyyy-MM-dd".
   * The value set may be {@code null}.
   */
  public DateRange setEndDate(DateTime endDate) {
    this.endDate = endDate;
    return this;
  }

  /**
   * The kind of resource this is, in this case dfareporting#dateRange.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind of resource this is, in this case dfareporting#dateRange.
   * The value set may be {@code null}.
   */
  public DateRange setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The date range relative to the date of when the report is run, one of: - "TODAY"  - "YESTERDAY"
   * - "WEEK_TO_DATE"  - "MONTH_TO_DATE"  - "QUARTER_TO_DATE"  - "YEAR_TO_DATE"  - "PREVIOUS_WEEK"
   * - "PREVIOUS_MONTH"  - "PREVIOUS_QUARTER"  - "PREVIOUS_YEAR"  - "LAST_7_DAYS"  - "LAST_30_DAYS"
   * - "LAST_90_DAYS"  - "LAST_365_DAYS"  - "LAST_24_MONTHS"
   * The value returned may be {@code null}.
   */
  public String getRelativeDateRange() {
    return relativeDateRange;
  }

  /**
   * The date range relative to the date of when the report is run, one of: - "TODAY"  - "YESTERDAY"
   * - "WEEK_TO_DATE"  - "MONTH_TO_DATE"  - "QUARTER_TO_DATE"  - "YEAR_TO_DATE"  - "PREVIOUS_WEEK"
   * - "PREVIOUS_MONTH"  - "PREVIOUS_QUARTER"  - "PREVIOUS_YEAR"  - "LAST_7_DAYS"  - "LAST_30_DAYS"
   * - "LAST_90_DAYS"  - "LAST_365_DAYS"  - "LAST_24_MONTHS"
   * The value set may be {@code null}.
   */
  public DateRange setRelativeDateRange(String relativeDateRange) {
    this.relativeDateRange = relativeDateRange;
    return this;
  }

  /**
   * The start date of the date range, inclusive. A string of the format: "yyyy-MM-dd".
   * The value returned may be {@code null}.
   */
  public DateTime getStartDate() {
    return startDate;
  }

  /**
   * The start date of the date range, inclusive. A string of the format: "yyyy-MM-dd".
   * The value set may be {@code null}.
   */
  public DateRange setStartDate(DateTime startDate) {
    this.startDate = startDate;
    return this;
  }

}
