/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.dfareporting.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;

/**
 * Represents a File resource. A File contains the meta-data for a report run. It shows the status
 * of the run and holds the urls to the generated report data if the run is finished and the status
 * is "REPORT_AVAILABLE".
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the DFA Reporting API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class File extends GenericJson {

  /**
   * The date range for which the file has report data. The date range will always be the absolute
   * date range for which the report is run.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateRange dateRange;

  /**
   * The eTag of this response for caching purposes.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String etag;

  /**
   * The file name of the file.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String fileName;

  /**
   * The output format of the report. Only available once the file is available.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String format;

  /**
   * The unique ID of this report file.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long id;

  /**
   * The kind of resource this is, in this case dfareporting#file.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The timestamp in milliseconds since epoch when this file was last modified.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long lastModifiedTime;

  /**
   * The ID of the report this file was generated from.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long reportId;

  /**
   * The status of the report file, one of: - "PROCESSING"  - "REPORT_AVAILABLE"  - "FAILED"  -
   * "CANCELLED"
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String status;

  /**
   * The urls where the completed report file can be downloaded.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Urls urls;

  /**
   * The date range for which the file has report data. The date range will always be the absolute
   * date range for which the report is run.
   * The value returned may be {@code null}.
   */
  public DateRange getDateRange() {
    return dateRange;
  }

  /**
   * The date range for which the file has report data. The date range will always be the absolute
   * date range for which the report is run.
   * The value set may be {@code null}.
   */
  public File setDateRange(DateRange dateRange) {
    this.dateRange = dateRange;
    return this;
  }

  /**
   * The eTag of this response for caching purposes.
   * The value returned may be {@code null}.
   */
  public String getEtag() {
    return etag;
  }

  /**
   * The eTag of this response for caching purposes.
   * The value set may be {@code null}.
   */
  public File setEtag(String etag) {
    this.etag = etag;
    return this;
  }

  /**
   * The file name of the file.
   * The value returned may be {@code null}.
   */
  public String getFileName() {
    return fileName;
  }

  /**
   * The file name of the file.
   * The value set may be {@code null}.
   */
  public File setFileName(String fileName) {
    this.fileName = fileName;
    return this;
  }

  /**
   * The output format of the report. Only available once the file is available.
   * The value returned may be {@code null}.
   */
  public String getFormat() {
    return format;
  }

  /**
   * The output format of the report. Only available once the file is available.
   * The value set may be {@code null}.
   */
  public File setFormat(String format) {
    this.format = format;
    return this;
  }

  /**
   * The unique ID of this report file.
   * The value returned may be {@code null}.
   */
  public Long getId() {
    return id;
  }

  /**
   * The unique ID of this report file.
   * The value set may be {@code null}.
   */
  public File setId(Long id) {
    this.id = id;
    return this;
  }

  /**
   * The kind of resource this is, in this case dfareporting#file.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind of resource this is, in this case dfareporting#file.
   * The value set may be {@code null}.
   */
  public File setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The timestamp in milliseconds since epoch when this file was last modified.
   * The value returned may be {@code null}.
   */
  public Long getLastModifiedTime() {
    return lastModifiedTime;
  }

  /**
   * The timestamp in milliseconds since epoch when this file was last modified.
   * The value set may be {@code null}.
   */
  public File setLastModifiedTime(Long lastModifiedTime) {
    this.lastModifiedTime = lastModifiedTime;
    return this;
  }

  /**
   * The ID of the report this file was generated from.
   * The value returned may be {@code null}.
   */
  public Long getReportId() {
    return reportId;
  }

  /**
   * The ID of the report this file was generated from.
   * The value set may be {@code null}.
   */
  public File setReportId(Long reportId) {
    this.reportId = reportId;
    return this;
  }

  /**
   * The status of the report file, one of: - "PROCESSING"  - "REPORT_AVAILABLE"  - "FAILED"  -
   * "CANCELLED"
   * The value returned may be {@code null}.
   */
  public String getStatus() {
    return status;
  }

  /**
   * The status of the report file, one of: - "PROCESSING"  - "REPORT_AVAILABLE"  - "FAILED"  -
   * "CANCELLED"
   * The value set may be {@code null}.
   */
  public File setStatus(String status) {
    this.status = status;
    return this;
  }

  /**
   * The urls where the completed report file can be downloaded.
   * The value returned may be {@code null}.
   */
  public Urls getUrls() {
    return urls;
  }

  /**
   * The urls where the completed report file can be downloaded.
   * The value set may be {@code null}.
   */
  public File setUrls(Urls urls) {
    this.urls = urls;
    return this;
  }

  /**
   * The urls where the completed report file can be downloaded.
   */
  public static final class Urls extends GenericJson {

    /**
     * The url for downloading the report data through the API.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String apiUrl;

    /**
     * The url for downloading the report data through a browser.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String browserUrl;

    /**
     * The url for downloading the report data through the API.
     * The value returned may be {@code null}.
     */
    public String getApiUrl() {
      return apiUrl;
    }

    /**
     * The url for downloading the report data through the API.
     * The value set may be {@code null}.
     */
    public Urls setApiUrl(String apiUrl) {
      this.apiUrl = apiUrl;
      return this;
    }

    /**
     * The url for downloading the report data through a browser.
     * The value returned may be {@code null}.
     */
    public String getBrowserUrl() {
      return browserUrl;
    }

    /**
     * The url for downloading the report data through a browser.
     * The value set may be {@code null}.
     */
    public Urls setBrowserUrl(String browserUrl) {
      this.browserUrl = browserUrl;
      return this;
    }

  }
}
