/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.dfareporting.model;

import com.google.api.client.json.GenericJson;

/**
 * Represents fields that are compatible to be selected for a report of type "PATH_TO_CONVERSION".
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the DFA Reporting API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class PathToConversionReportCompatibleFields extends GenericJson {

  /**
   * Conversion dimensions which are compatible to be selected in the "conversionDimensions" section
   * of the report.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Dimension> conversionDimensions;

  static {
    // hack to force ProGuard to consider Dimension used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Dimension.class);
  }

  /**
   * Custom floodlight variables which are compatible to be selected in the
   * "customFloodlightVariables" section of the report.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Dimension> customFloodlightVariables;

  static {
    // hack to force ProGuard to consider Dimension used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Dimension.class);
  }

  /**
   * The kind of resource this is, in this case dfareporting#pathToConversionReportCompatibleFields.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * Metrics which are compatible to be selected in the "metricNames" section of the report.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Metric> metrics;

  static {
    // hack to force ProGuard to consider Metric used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Metric.class);
  }

  /**
   * Per-interaction dimensions which are compatible to be selected in the
   * "perInteractionDimensions" section of the report.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Dimension> perInteractionDimensions;

  static {
    // hack to force ProGuard to consider Dimension used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Dimension.class);
  }

  /**
   * Conversion dimensions which are compatible to be selected in the "conversionDimensions" section
   * of the report.
   * The value returned may be {@code null}.
   */
  public java.util.List<Dimension> getConversionDimensions() {
    return conversionDimensions;
  }

  /**
   * Conversion dimensions which are compatible to be selected in the "conversionDimensions" section
   * of the report.
   * The value set may be {@code null}.
   */
  public PathToConversionReportCompatibleFields setConversionDimensions(java.util.List<Dimension> conversionDimensions) {
    this.conversionDimensions = conversionDimensions;
    return this;
  }

  /**
   * Custom floodlight variables which are compatible to be selected in the
   * "customFloodlightVariables" section of the report.
   * The value returned may be {@code null}.
   */
  public java.util.List<Dimension> getCustomFloodlightVariables() {
    return customFloodlightVariables;
  }

  /**
   * Custom floodlight variables which are compatible to be selected in the
   * "customFloodlightVariables" section of the report.
   * The value set may be {@code null}.
   */
  public PathToConversionReportCompatibleFields setCustomFloodlightVariables(java.util.List<Dimension> customFloodlightVariables) {
    this.customFloodlightVariables = customFloodlightVariables;
    return this;
  }

  /**
   * The kind of resource this is, in this case dfareporting#pathToConversionReportCompatibleFields.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind of resource this is, in this case dfareporting#pathToConversionReportCompatibleFields.
   * The value set may be {@code null}.
   */
  public PathToConversionReportCompatibleFields setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * Metrics which are compatible to be selected in the "metricNames" section of the report.
   * The value returned may be {@code null}.
   */
  public java.util.List<Metric> getMetrics() {
    return metrics;
  }

  /**
   * Metrics which are compatible to be selected in the "metricNames" section of the report.
   * The value set may be {@code null}.
   */
  public PathToConversionReportCompatibleFields setMetrics(java.util.List<Metric> metrics) {
    this.metrics = metrics;
    return this;
  }

  /**
   * Per-interaction dimensions which are compatible to be selected in the
   * "perInteractionDimensions" section of the report.
   * The value returned may be {@code null}.
   */
  public java.util.List<Dimension> getPerInteractionDimensions() {
    return perInteractionDimensions;
  }

  /**
   * Per-interaction dimensions which are compatible to be selected in the
   * "perInteractionDimensions" section of the report.
   * The value set may be {@code null}.
   */
  public PathToConversionReportCompatibleFields setPerInteractionDimensions(java.util.List<Dimension> perInteractionDimensions) {
    this.perInteractionDimensions = perInteractionDimensions;
    return this;
  }

}
